/***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************/

#ifndef VERSION_H
#define VERSION_H

#define KMYFIREWALL_VERSION "1.0"
#define COPYRIGHT_DATE "(c) 2002-2005"
#define COPYRIGHT_OWNER "The KMyFirewall Team"
#define COPYRIGHT_STRING "copyright (c) the KMyFirewall developers 2002-2005"
#define MAINTAINER "Christian Hubinger <chubinegr@sedisys.com>"
#endif
